littletable.JoinTerm

Module littletable :: Class JoinTerm |
[frames] | no frames]

# Class JoinTerm

source code

    object --+
             |
            JoinTerm

Temporary object created while composing a join across tables using Table.join_on and '+' addition. JoinTerm's are usually created by calling join_on on a Table object, as in:

       customers.join_on("id") + orders.join_on("custid")

This join expression would set up the join relationship equivalent to:

       customers.join(orders, id="custid")

If tables are being joined on attributes that have the same name in both tables, then a join expression could be created by adding a JoinTerm of one table directly to the other table:

       customers.join_on("custid") + orders

Once the join expression is composed, the actual join is performed using function call notation:

       customerorders = customers.join_on("custid") + orders
       for custord in customerorders():
           print custord

When calling the join expression, you can optionally specify a list of attributes as defined in Table.join.

Instance Methods
__init__(self, sourceTable, joinfield) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__add__(self, other) | source code
__radd__(self, other) | source code
__call__(self, attrs=None) | source code
join_on(self, col) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, sourceTable, joinfield) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)